@@ -323,7 +323,7 @@ tanh.torch_tensor <- function(x) {
 
 #' @export
 max.torch_tensor <- function(..., na.rm = FALSE) {
-  if (na.rm) stop("Torch tensors do not have NAs!")
+  if (na.rm) value_error("Torch tensors do not have NAs!")
   l <- list(...)
   l_max <- lapply(l, torch_max)
   Reduce(function(x, y) torch_max(x, other = y), l_max)
@@ -331,7 +331,7 @@ max.torch_tensor <- function(..., na.rm = FALSE) {
 
 #' @export
 min.torch_tensor <- function(..., na.rm = FALSE) {
-  if (na.rm) stop("Torch tensors do not have NAs!")
+  if (na.rm) value_error("Torch tensors do not have NAs!")
   l <- list(...)
   l_min <- lapply(l, torch_min)
   Reduce(function(x, y) torch_min(x, other = y), l_min)
@@ -339,7 +339,7 @@ min.torch_tensor <- function(..., na.rm = FALSE) {
 
 #' @export
 prod.torch_tensor <- function(..., dim, keepdim = FALSE, na.rm = FALSE) {
-  if (na.rm) stop("Torch tensors do not have NAs!")
+  if (na.rm) value_error("Torch tensors do not have NAs!")
   l <- list(...)
   if (length(l) == 1) {
     if (!missing(dim)) {
@@ -355,7 +355,7 @@ prod.torch_tensor <- function(..., dim, keepdim = FALSE, na.rm = FALSE) {
 
 #' @export
 sum.torch_tensor <- function(..., dim, keepdim = FALSE, na.rm = FALSE) {
-  if (na.rm) stop("Torch tensors do not have NAs!")
+  if (na.rm) value_error("Torch tensors do not have NAs!")
   l <- list(...)
   if (length(l) == 1) {
     if (!missing(dim)) {
@@ -371,7 +371,7 @@ sum.torch_tensor <- function(..., dim, keepdim = FALSE, na.rm = FALSE) {
 
 #' @export
 mean.torch_tensor <- function(x, dim, keepdim = FALSE, na.rm = FALSE, ...) {
-  if (na.rm) stop("Torch tensors do not have NAs!")
+  if (na.rm) value_error("Torch tensors do not have NAs!")
   if (!missing(dim)) {
     torch_mean(x, dim, keepdim)
   } else {
