@@ -211,10 +211,19 @@ test_that("logit works", {
   expect_equal_to_tensor(
     exp(torch_logit(x)) / (1 + exp(torch_logit(x))),
     x,
-    tol = 1e-6
+    tolerance = 1e-6
   )
 })
 
+test_that("std works", {
+  x <- torch_randn(10)
+  
+  s <- torch_std(x)
+  r <- sd(as.numeric(x))
+  
+  expect_equal_to_r(s, r, tolerance = 1e-6)
+})
+
 test_that("tensordot", {
   a <- torch_arange(start = 1, end = 60)$reshape(c(3, 4, 5))
   b <- torch_arange(start = 1, end = 24)$reshape(c(4, 3, 2))
