@@ -1,6 +1,6 @@
 test_that("R-level error messages are correctly translated in FR", {
   # skip on ubuntu cuda as image as no FR lang installed
-  skip_if(torch::cuda_is_available() && grepl("linux-gnu", R.version$os))
+  skip_if(torch::cuda_is_available() && is_linux())
   # skip on MAC M1
   skip_if(torch::backends_mps_is_available() && R.version$arch == "aarch64")
   withr::with_language(lang = "fr",
@@ -14,7 +14,7 @@ test_that("R-level error messages are correctly translated in FR", {
 
 test_that("R-level warning messages are correctly translated in FR", {
   # skip on ubuntu cuda as image as no FR lang installed
-  skip_if(torch::cuda_is_available() && grepl("linux-gnu", R.version$os))
+  skip_if(torch::cuda_is_available() && is_linux())
   # skip on MAC M1
   skip_if(torch::backends_mps_is_available() && R.version$arch == "aarch64")
   x <- torch_randn(2, requires_grad = TRUE)
@@ -30,3 +30,28 @@ test_that("R-level warning messages are correctly translated in FR", {
   )
 })
 
+test_that("installer_message gets correctly translated in FR", {
+  skip_if(torch::cuda_is_available() && is_linux())
+  skip_if(torch::backends_mps_is_available() && R.version$arch == "aarch64")
+  withr::with_envvar(new = c("TORCH_INSTALL_DEBUG" = TRUE),  
+    withr::with_language(lang = "fr",
+       expect_message(
+         torch:::nvcc_version_from_path(tempfile()),
+        regexp = "Tentative de lancer nvcc depuis",
+        fixed = TRUE
+      )
+  ))
+})
+
+test_that("cli_abort gets correctly translated in FR", {
+  skip_if(torch::cuda_is_available() && is_linux())
+  skip_if(torch::backends_mps_is_available() && R.version$arch == "aarch64")
+    withr::with_language(lang = "fr",
+       expect_error(
+         torch:::check_supported_version("7.3.2", c("10.1", "10.2")),
+        regexp = "La version de CUDA ",
+        fixed = TRUE
+      )
+  )
+})
+
